@@ -33,7 +33,7 @@ import parser, soundcard
 import string, types
 from musicalpitch import MusicalPitch
 from interval import Interval
-from mpdutils import notename_to_int, int_to_notename
+from mpdutils import notename_to_int, int_to_notename, int_to_user_notename
 
 from _exceptions import MpdException
 
