@@ -46,6 +46,12 @@ class dim20:
 
 dimentions = {20: dim20}
 
+accidental_y_offset = {const.ACCIDENTAL__2: -7,
+                       const.ACCIDENTAL__1: -7,
+                       const.ACCIDENTAL_0: -5,
+                       const.ACCIDENTAL_1: -6,
+                       const.ACCIDENTAL_2: -2}
+
 class Engraver:
     def __init__(self, timepos, fontsize):
         self.m_fontsize = 20
@@ -160,19 +166,14 @@ class AccidentalsEngraver(Engraver):
         x = 0
         for y in self.m_accs.keys():
             for acc in self.m_accs[y]:
-                y_offset = {const.ACCIDENTAL__2: -7,
-                            const.ACCIDENTAL__1: -7,
-                            const.ACCIDENTAL_0: -5,
-                            const.ACCIDENTAL_1: -6,
-                            const.ACCIDENTAL_2: -2}
                 im = gtk.Image()
                 im.set_from_file(fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, acc))
                 im.get_pixbuf().render_to_drawable(widget.window, gc,
                         0, 0,
                         self.m_xpos + x,
-                        y_offset[acc] + staff_yoffset
+                        accidental_y_offset[acc] + staff_yoffset
                          + dimentions[self.m_fontsize].linespacing*y/2
-                         + y_offset[acc],
+                         + accidental_y_offset[acc],
                         -1, -1, gtk.gdk.RGB_DITHER_NONE, 0, 0)
                 x += dimentions[self.m_fontsize].accidental_widths[acc] + 1
 
@@ -201,19 +202,13 @@ class KeySignatureEngraver(Engraver):
                 type = 2
             else:
                 type = 1
-            #FIXME duplicated elsewhere
-            y_offset = {const.ACCIDENTAL__2: -7,
-                    const.ACCIDENTAL__1: -7,
-                    const.ACCIDENTAL_0: -5,
-                    const.ACCIDENTAL_1: -6,
-                    const.ACCIDENTAL_2: -2}
             im = gtk.Image()
             im.set_from_file(fetadir+'/feta%i-accidentals-%i.xpm' % (self.m_fontsize, type))
             im.get_pixbuf().render_to_drawable(widget.window, gc, 0, 0,
                     self.m_xpos + x,
-                    y_offset[type] + staff_yoffset
+                    accidental_y_offset[type] + staff_yoffset
                      + dimentions[self.m_fontsize].linespacing*ypos/2
-                     + y_offset[type], -1, -1,
+                     + accidental_y_offset[type], -1, -1,
                      gtk.gdk.RGB_DITHER_NONE, 0, 0)
             #FIXME see FIXME msg in .get_width
             x += 10
