@@ -1,7 +1,7 @@
-#!/usr/bin/python
+#!/usr/bin/python2.2
 
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,35 +20,26 @@
 # This script is used to launch Solfege when running
 # it from the source dir without installing.
 
-#from __future__ import nested_scopes
-
-#import gc
-#gc.set_debug(gc.DEBUG_LEAK)
-#gc.disable()
-
 import sys
 
-if sys.version_info < (2, 1):
-    print "Solfege need Python 2.1 or newer. Your python seems to be too old."
-    print "Do not report bugs in Solfege before you upgrade your python interpreter."
+if sys.version_info < (2, 2):
+    print "********************************************************************"
+    print "Solfege need Python 2.2 or newer. The configure script told you so!"
+    print "********************************************************************"
+    sys.exit(-1)
 
+import src
 import src.configureoutput
 
+src.configureoutput.prefix = "."
+
 import src.rcfile
-src.rcfile.copy_rc14_file()
+src.rcfile.copy_rc_file()
 import src.cfg
 
 src.cfg.initialise(None, "default.config", "~/.solfegerc%i.%i" %
   (src.configureoutput.MAJOR_VERSION, src.configureoutput.MINOR_VERSION))
 
-if not src.configureoutput.WITH_GNOME:
-    sys.path.insert(0, "gnomeemu")
-
-import src.i18n
-src.i18n.initialise("share/locale")
-
-import __main__, time
-__main__._st = time.clock()
 if '--txtui' in sys.argv:
     import src.txtui
 else:
