@@ -64,5 +64,6 @@ class AbstractSynth:
             solfege_c_midi.sndctl_seq_reset()
             os.close(solfege_c_midi.cvar.seqfd)
             solfege_c_midi.cvar.seqfd = -1
-
+    def stop(self):
+        solfege_c_midi.sndctl_seq_reset()
 
