@@ -242,7 +242,6 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
         vbox.pack_start(self.practise_box)
 
         self.action_area = gtk.HBox()
-        self.action_area.set_size_request(-1, self.get_int("gui/button_height"))
         self.action_area.show()
         vbox.pack_end(self.action_area, gtk.FALSE)
 
@@ -329,8 +328,7 @@ class IntervalGui(Gui):
 
         self.g_new_interval = gu.bButton(self.action_area, _("_New interval"),
                                           self.new_question)
-        self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
-                   lambda _o, self=self: self.m_t.play_question())
+        self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
         self.g_repeat.set_sensitive(gtk.FALSE)
         self.setup_key_bindings()
     def select_inputwidget(self):
@@ -376,6 +374,9 @@ class IntervalGui(Gui):
         self.m_key_bindings = {}
         for idx in range(len(keys)):
             self.m_key_bindings['interval_input/'+keys[idx]] = lambda idx=idx, self=self: self.click_on_interval(1, idx+1, None)
+    def repeat_question(self, *w):
+        self.m_t.play_question()
+        self.g_input.grab_focus_first_sensitive_button()
 
 
 class LessonbasedGui(Gui):
