@@ -21,8 +21,6 @@ TODO:
     - watches outside ConfigUtils
 >>> import cfg
 >>> cfg.initialise(None, "default.config", "~/.cfg-test")
->>> cfg.get_int("gui/button_height")
-40
 >>> cfg.set_string("section/stringvar", "value")
 >>> cfg.get_string("section/stringvar")
 'value'
@@ -105,7 +103,7 @@ def parse_file_into_dict(dict, filename):
             pass
         else:
            print filename
-           raise "X", line
+           raise Exception("Shit happended line %s" % line)
         line = file.readline()
     file.close()
     return dict
@@ -269,7 +267,7 @@ def initialise(app_defaults_filename, system_filename, user_filename):
         try:
             data = parse_file_into_dict({}, app_defaults_filename)
         except:
-            raise "Solfege install is completely broken.\nCannot find required file %s" % app_defaults_filename
+            raise Exception("Solfege install is completely broken.\nCannot find required file %s" % app_defaults_filename)
     else:
         data = {}
     if system_filename and os.path.isfile(system_filename):
