@@ -345,7 +345,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
     def on_help(self, *v):
         #FIXME It is stupid to display this help in the main window.
         self.m_app.handle_href("preferences-window.html")
-    def on_changed(self, _o=None):
+    def on_changed(self, *_o):
         if self._is_alive:
             self.set_modified(gtk.TRUE)
     def on_apply(self, _o, pagenum):
@@ -359,12 +359,12 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
             self.set_int('config/preferred_instrument',
                          self.g_instrsel.m_instrument)
             self.set_int('config/preferred_instrument_velocity',
-                         self.g_instrsel.g_velocity.get_value_as_int())
+                         self.g_instrsel.g_velocity.get_value())
         if pagenum == 1:
             self.set_string('user/lowest_pitch',
-                mpd.int_to_notename(self.g_lowest_singable.get_value_as_int()))
+                mpd.int_to_notename(self.g_lowest_singable.get_value()))
             self.set_string('user/highest_pitch',
-                mpd.int_to_notename(self.g_highest_singable.get_value_as_int()))
+                mpd.int_to_notename(self.g_highest_singable.get_value()))
             if self.g_sex_male.get_active():
                 self.set_string('user/sex', 'male')
             else:
