@@ -20,33 +20,41 @@ if __name__ == "__main__":
     sys.path.append(".")
 import gettext, i18n
 import re, string
-tokens = (
- 'NAME', 'EQUALS', 'STRING', 'I18NSTRING', 'INTEGER', 'LBRACE',
- 'RBRACE', 'COMMENT', 'PLUS', 'COMMA', 'PERCENT', 'DIVIDE',
- 'BLOCKSTART', 'EQUALS_EXP', 'PLUS_EXP', 'DIVIDE_EXP', 'PERCENT_EXP',
- 'COMMA_EXP', 'TEMPO', 'INCLUDE')
+
+tokens = ('NAME', 'STRING', 'INTEGER', 'CHAR', 'BLOCKSTART', 'FUNCTIONCALL')
 
 for t in tokens:
     globals()[t] = t
 
-re_INCLUDE = re.compile("include*\(([\w-]*)\)")
-re_ALL = re.compile(r"""
-            (?P<keyword>[a-zA-Z]+[\w_-]*(\(.*?\))?)|
-        ###### xstring
-          (
-           \"\"\"(?P<xstring>(.*?))\"\"\"
-           )|
-        ###### string
-            ((?P<i18npre>_\()?\"
-            (?P<string>[^\"]*)
-            \"(?P<i18npost>\))?)|
-        ###### integer
-            (?P<integer>-?\d+)|
-        ###### rational
-            (?P<rat_num>\d+)/(?P<rat_den>\d+)|
-        ###### comment
-            (?P<comment>\#.*?$)
-            """, re.VERBOSE|re.MULTILINE|re.DOTALL)
+re_FUNCTION = re.compile("(?P<func>[a-zA-Z]+\w*?)\((?P<params>.*?)\)")#FIXME
+
+NEW_re = re.compile("""(?:
+                        (\s+)|
+                        (\#.*?$)|
+                        (-?\d+)|
+                        (\"\"\"(.*?)\"\"\")|
+                        ("(.*?)")|
+                        ([_\w]+[a-zA-Z-_1-9]*)
+                )""",
+                      re.VERBOSE|re.MULTILINE|re.DOTALL)
+
+LI_INTEGER = NEW_re.match("-3").lastindex
+LI_MSTRING = NEW_re.match('"""string"""').lastindex
+LI_STRING = NEW_re.match('"string"').lastindex
+LI_NAME = NEW_re.match("name").lastindex
+LI_COMMENT = NEW_re.match("# comment").lastindex
+
+lastindex_to_ID = {LI_INTEGER: INTEGER,
+                     LI_STRING: STRING,
+                     LI_MSTRING: STRING,
+                     LI_NAME: NAME,
+                    }
+
+lastindex_to_group = {LI_INTEGER: 3,
+                     LI_STRING: 7,
+                     LI_MSTRING: 5,
+                     LI_NAME: 8,
+                    }
 
 class DataparserException(Exception):
     def __init__(self, filename, lineno, badcode):
@@ -58,8 +66,9 @@ class DataparserException(Exception):
 
 
 class Dataparser:
-    def __init__(self, globals={}, gd=[]):
+    def __init__(self, globals={}, function_dict={}, gd=[]):
         self.m_globals = globals
+        self.m_function_dict = function_dict
         self.m_gd = gd
     def parse_file(self, filename, only_header=0):
         self.m_filename = [filename]
@@ -67,19 +76,19 @@ class Dataparser:
         self.m_blocks = []
         context = self.m_globals
         v = self.get_tokens(filename, only_header)
-        v = self.do_include(v)
-        for op in (PERCENT, PLUS, DIVIDE, COMMA, EQUALS):
+        v = self.do_functioncall(v)
+        for op in ('%', '+', '/', ',', '='):
             v = self.do_simple_op(v, op)
         v = self.do_blockstart(v)
         for ex in v:
-            if ex[0] == EQUALS_EXP:
+            if ex[0] == '=_EXP':
                 context[ex[1][1]] = self.evaluate(ex[2])
             elif ex[0] == BLOCKSTART:
                 assert context == self.m_globals
                 self.m_blocks.append({})
                 context = self.m_blocks[-1]
                 context['blocktype'] = ex[1][1]
-            elif ex[0] == RBRACE:
+            elif ex[1] == '}':
                 for n in self.m_gd:
                     if not context.has_key(n):
                         context[n] = self.m_globals[n]
@@ -89,12 +98,12 @@ class Dataparser:
                 # "this is a string" as
                 # music = "this is a string"
                 context['music'] = ex[1]
-            elif ex[0] == PERCENT_EXP:
+            elif ex[0] == '%_EXP':
                 # the shortcut that interprets a single string
                 # "this is a string" as
                 # music = "this is a string"
                 context['music'] = self.evaluate(ex)
-            elif ex[0] == PLUS_EXP:
+            elif ex[0] == '+_EXP':
                 # the shortcut that interprets a single string
                 # "this is a string" as
                 # music = "this is a string"
@@ -110,112 +119,51 @@ class Dataparser:
         f = open(filename, "r")
         s = f.read()
         f.close()
-        linecount = 1
-        p = 0
         v = []
-        slen = len(s)
-        while p < slen:
-            # doing simple comparations is faster than using a
-            # regular expression
-            if s[p] in " \n\t{=}%+,/":
-                if s[p] == ' ':
-                    p += 1
+        pos = 0
+        lineno = 1
+        while 1:
+            try:
+                if s[pos] in " \n\t{}=%+,/()":
+                    if s[pos] in ' \t':
+                        pos += 1
+                        continue
+                    if s[pos] == '\n':
+                        pos += 1
+                        lineno += 1
+                        continue
+                    v.append((CHAR, s[pos], filename, lineno))
+                    pos += 1
                     continue
-                if s[p] == '\n':
-                    p += 1
-                    linecount += 1
-                    continue
-                if s[p] == '\t':
-                    p += 1
-                    continue
-                if s[p] == '{':
-                    p += 1
-                    v.append((LBRACE, '{', filename, linecount))
-                    continue
-                elif s[p] == '=':
-                    p += 1
-                    v.append((EQUALS, '=', filename, linecount))
-                    continue
-                elif s[p] == '}':
-                    p += 1
-                    v.append((RBRACE, '}', filename, linecount))
-                    if first_block_only:
-                        break
-                    continue
-                elif s[p] == '%':
-                    p += 1
-                    v.append((PERCENT, '%', filename, linecount))
-                    continue
-                elif s[p] == '+':
-                    p += 1
-                    v.append((PLUS, '+', filename, linecount))
-                    continue
-                elif s[p] == ',':
-                    p += 1
-                    v.append((COMMA, ',', filename, linecount))
-                    continue
-                elif s[p] == '/':
-                    p += 1
-                    v.append((DIVIDE, '/', filename, linecount))
-                    continue
-            m = re_ALL.match(s[p:])
-            if m:
-                if m.group('integer'):
-                    p += m.end()
-                    v.append((INTEGER, int(m.group('integer')),
-                              filename, linecount))
-                    continue
-                if m.group('string'):
-                    p += m.end()
-                    linecount = linecount + string.count(m.group(), '\n')
-                    if m.group('i18npre'):
-                        v.append((I18NSTRING, m.group('string'),
-                                  filename, linecount))
-                    else:
-                        v.append((STRING, m.group('string'),
-                                  filename, linecount))
-                    continue
-                elif m.group('xstring'):
-                    #FIXME can't xstring and string be joined in the regex?
-                    p += m.end()
-                    linecount += string.count(m.group(), '\n')
-                    v.append((STRING, m.group('xstring'), filename, linecount))
-                    continue
-                elif m.group('keyword'):
-                    p += m.end()
-                    im = re_INCLUDE.match(m.group('keyword'))
-                    if im:
-                        v.append((INCLUDE, im.groups()[0], filename, linecount))
-                    else:
-                        v.append((NAME, m.group('keyword'), filename, linecount))
-                    continue
-                elif m.group('comment'):
-                    p += m.end()
-                    continue
-                elif m.group('rat_num'):
-                    p += m.end()
-                    v.append((TEMPO, (int(m.group('rat_num')),
-                                      int(m.group('rat_den')))))
-                    continue
-                else:
-                    raise DataparserException(filename, linecount, s[p:p+10])
+            except IndexError:
+                break
+            m = NEW_re.match(s, pos)
+            if not m:
+                break
+            if m.lastindex == LI_COMMENT:
+                pass
             else:
-                raise DataparserException(filename, linecount, s[p:p+10])
+                v.append((lastindex_to_ID[m.lastindex], m.group(lastindex_to_group[m.lastindex]), filename, lineno))
+            pos = m.end()
         return v
-    def do_include(self, list):
+    def do_functioncall(self, list):
         x = 0
         while x < len(list):
-            if list[x][0] == INCLUDE:
-                fn = os.path.join(os.path.dirname(self.m_filename[-1]),
-                                  list[x][1])
-                list[x:x+1] = self.get_tokens(fn, 0)
+            if list[x][0] == NAME \
+                        and list[x+1][1] == '(' and list[x+3][1] == ')':
+                if list[x][1] == 'include':
+                    fn = os.path.join(os.path.dirname(self.m_filename[-1]),
+                                      list[x+2][1])
+                    list[x:x+4] = self.get_tokens(fn, 0)#+['FILE_END']#well pop header stack FIXME
+                else:
+                    list[x:x+4] = [(FUNCTIONCALL, list[x][1], list[x+2][1])]
             x = x + 1
         return list
     def do_simple_op(self, list, op):
         x = 1
         s = '%s_EXP' % op
         while x + 1 < len(list):
-            if list[x][0] is op:
+            if list[x][1] == op:
                 list[x-1:x+2]=[(s, list[x-1], list[x+1])]
             else:
                 x += 1
@@ -223,29 +171,27 @@ class Dataparser:
     def do_blockstart(self, list):
         x = 0
         while x < len(list):
-            if list[x][0] is NAME and list[x+1][0] is LBRACE:
-                list[x:x+2]=[('BLOCKSTART', list[x])]
+            if list[x][0] is NAME and list[x+1][1] == '{':
+                list[x:x+2]=[(BLOCKSTART, list[x])]
             else:
                 x += 1
         return list
     def evaluate(self, exp):
-        if exp[0] == DIVIDE_EXP:
+        if exp[0] == '/_EXP':
             return int(exp[1][1]), int(exp[2][1])
         elif exp[0] == STRING:
             return exp[1]
-        elif exp[0] == I18NSTRING:
-            return _(exp[1])
         elif exp[0] == INTEGER:
-            return exp[1]
-        elif exp[0] == PLUS_EXP:
+            return int(exp[1])
+        elif exp[0] == '+_EXP':
             return self.evaluate(exp[1]) + self.evaluate(exp[2])
-        elif exp[0] == PERCENT_EXP:
+        elif exp[0] == '%_EXP':
             if exp[1][0] is NAME:
                 A = self.evaluate(exp[1])
             else:
                 A = exp[1][1]
             return A % exp[2][1]
-        elif exp[0] == COMMA_EXP:
+        elif exp[0] == ',_EXP':
             A = self.evaluate(exp[1])
             B = self.evaluate(exp[2])
             if type(A) == type([]):
@@ -254,9 +200,9 @@ class Dataparser:
                 return [A, B]
         elif exp[0] == NAME:
             return self.m_globals[exp[1]]
-        else:
-            assert exp[0] == TEMPO
-            return exp[1]
+        else:# exp[0] == 'FUNCTIONCALL':
+            assert exp[0] == 'FUNCTIONCALL'
+            return self.m_function_dict[exp[1]](exp[2])
 
 def get_translated_string(dict, name):
     for n in i18n.langs():
@@ -285,30 +231,22 @@ def __f():
                       'vertic': 'vertic',
                       'yes': 1,
                       'no': 0,
-                      'tempo': (160, 4)})
-        for x in range(10):
+                      'accidentals': 'accidentals',
+                      'tempo': (160, 4)},
+                      {'_': _})
+        for x in range(30):
             p.parse_file(fn)
-        for b in p.m_blocks:
-            print b
+            #p.get_tokens(fn, 0)
     print time.clock() - t1
+    for i in p.get_tokens(fn, 0):
+        print i
 
-def _benchmark_tokenizer():
-    import time
-    n = 40
-    p = Dataparser()
-    t1 = time.clock()
-    for fn in sys.argv[1:]:
-        if os.path.isfile(fn) and (os.path.basename(fn) != 'Makefile'):
-            for x in range(n):
-                v = p.get_tokens(fn, 0)
-    t2 = time.clock()
-    return t2-t1
 
 if __name__ == "__main__":
     import i18n
-    #print _benchmark_tokenizer()
     __f()
-    #import profile, pstats
-    #profile.run("__f()", "profile.txt")
-    #s = pstats.Stats("profile.txt")
-    #s.strip_dirs().sort_stats('cumulative').print_stats(100)
+    sys.exit()
+    import profile, pstats
+    profile.run("__f()", "profile.txt")
+    s = pstats.Stats("profile.txt")
+    s.strip_dirs().sort_stats('cumulative').print_stats(100)
