@@ -15,6 +15,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+
+# We have the following to make module testing work.
+try:
+    if app_running == 'solfege':
+        pass
+except:
+    import sys; sys.path.append(".")
+    import src.i18n
+    import pygtk
+    pygtk.require('2.0')
+
+
 import re, string, types, os
 import const
 import random
@@ -23,6 +35,31 @@ from soundcard.rat import Rat
 
 import dataparser
 
+# The keys in the dict say how many steps up or down in the
+# circle of fifths we go if we transpose.
+_keys_to_interval = {
+              -10: '-M6', #c -> eses
+               -9: '-a2', #c -> beses
+               -8: '-a5', #c -> fes
+               -7: '-au', #c -> ces
+               -6: '-a4', #c -> ges
+               -5: 'm2', # c -> des
+               -4: '-M3',# c -> as
+               -3: 'm3', # c -> es
+               -2: '-M2', # c -> bes
+               -1: '4', # c -> f
+                0: 'u',
+                1: '-4', # c -> g,
+                2: 'M2', # c -> d
+                3: '-m3',# c -> a
+                4: 'M3', # c -> e
+                5: '-m2', # c -> b
+                6: 'a4', # c -> fis
+                7: 'au', #c -> cis
+                8: 'a5', # c -> gis
+                9: 'a2', # c -> dis
+                10: 'M6', # c -> ais
+            }
 
 predef = {'dictation': 'dictation',
           'progression': 'progression',
@@ -36,8 +73,15 @@ predef = {'dictation': 'dictation',
           'vertic': 'vertic',
           'yes': 1,
           'no': 0,
+          'accidentals': 'accidentals',
+          'key': 'key',
+          'semitones': 'semitones',
           'tempo': (60, 4)}
 
+lessonfile_functions = {
+        '_': _,
+}
+
 class _Header:
     def __init__(self, headerdict):
         self.m_headerdict = headerdict
@@ -55,7 +99,7 @@ class LessonfileCommon:
     def __init__(self):
         self.m_prev_question = None
     def _parse_file(self, filename):
-        parser = dataparser.Dataparser(predef, ('tempo',))
+        parser = dataparser.Dataparser(predef, lessonfile_functions, ('tempo',))
         parser.parse_file(filename)
         self._idx = 0
         self.m_transpose = mpd.MusicalPitch.new_from_notename("c'")
@@ -87,22 +131,73 @@ class LessonfileCommon:
             map(convert, self.m_questions)
     def select_random_question(self):
         """
-        Select a question by random. Set the self.m_transpose variable if
-        the lessonfile say the question should be transposed.
+        Select a new question by random.
         """
+        count = 0
         while 1:
+            count += 1
             self._idx = random.randint(0, len(self.m_questions) - 1)
-            if self.header.random_transpose == 1:
-                self.m_transpose = mpd.MusicalPitch().randomize("g", "fis'")
-            elif type(self.header.random_transpose) == type([]):
-                self.m_transpose = mpd.MusicalPitch().randomize(
-                  mpd.transpose_notename("c'", self.header.random_transpose[0]),
-                  mpd.transpose_notename("c'", self.header.random_transpose[1]))
+            if self.header.random_transpose:
+                if self.header.random_transpose == 1:
+                    self.handle_random_transpose_is_yes()
+                # to handle old style random_transpose = -4, 5
+                elif len(self.header.random_transpose) == 2:
+                    self.header.random_transpose \
+                        = ['semitones'] + self.header.random_transpose
+                if self.m_questions[self._idx].has_key('key'):
+                    key = self.m_questions[self._idx]['key']
+                else:
+                    key = "c \major"
+                if self.header.random_transpose[0] == 'semitones':
+                    self._semitone_find_random_transpose()
+                else:
+                    self._find_random_transpose(key)
+            if count == 10:
+                break
             if self.m_prev_question == self.get_music() \
                 and (len(self.m_questions) > 1 or self.header.random_transpose):
                 continue
             break
         self.m_prev_question = self.get_music()
+    def _semitone_find_random_transpose(self):
+        if self.header.random_transpose == 1:
+            self.m_transpose = mpd.MusicalPitch().randomize("g", "fis'")
+        elif type(self.header.random_transpose) == type([]):
+            self.m_transpose = mpd.MusicalPitch().randomize(
+              mpd.transpose_notename("c'", self.header.random_transpose[1]),
+              mpd.transpose_notename("c'", self.header.random_transpose[2]))
+    def _find_random_transpose(self, key):
+        """
+        Pick a random interval to transpose the question.
+        Set the variable self.m_transpose .
+        This function transposes in "accidentals" mode.
+        """
+        low, high = self.header.random_transpose[1:3]
+        tone, minmaj = string.split(key, " ")
+        k = mpd.MusicalPitch.new_from_notename(tone).get_octave_notename()
+        #FIXME this list say what key signatures are allowed in sing-chord
+        # lesson files. Get the correct values and document them.
+        kv = ['des', 'aes', 'ees', 'bes', 'f', 'c',
+              'g', 'd', 'a', 'e', 'b', 'fis', 'cis', 'gis']
+        # na tell the number of accidentals (# is positive, b is negative)
+        # the question has from the lessonfile before anything is transpose.
+        na = kv.index(k) - 5
+        if minmaj == '\\minor':
+            na -= 3
+        if self.header.random_transpose[0] == 'accidentals':
+            # the number of steps down the circle of fifths we can go
+            n_down = low - na
+            # the number of steps up the circle of fifths we can go
+            n_up = high - na
+        else:
+            assert self.header.random_transpose[0] == 'key'
+            n_down = low
+            n_up = high
+        interv = mpd.Interval()
+        interv.set_from_string(_keys_to_interval[random.choice(range(n_down, n_up+1))])
+        self.m_transpose = mpd.MusicalPitch.new_from_notename("c'") + interv
+    def handle_random_transpose_is_yes(self):
+        self.header.random_transpose = ['semitones', -5, 6]
     def get_tempo(self):
         return self.m_questions[self._idx]['tempo']
     def get_name(self):
@@ -151,7 +246,6 @@ class DictationLessonfile(LessonfileCommon):
         if self._idx < len(self.m_questions) -1:
             self._idx = self._idx + 1
 
-
 class SingChordLessonfile(LessonfileCommon):
     def __init__(self, filename):
         LessonfileCommon.__init__(self)
@@ -184,73 +278,8 @@ class SingChordLessonfile(LessonfileCommon):
             music = string.replace(music, r"\addvoice",
                       r"\addvoice\transpose %s" % self.m_transpose.get_octave_notename())
         return music
-    def select_random_question(self):
-        """
-        Select a new question by random.
-        """
-        while 1:
-            self._idx = random.randint(0, len(self.m_questions) - 1)
-            if self.header.random_transpose:
-                if self.m_questions[self._idx].has_key('key'):
-                    key = self.m_questions[self._idx]['key']
-                else:
-                    key = "c \major"
-                self.m_transpose = self._find_random_transpose(key)
-            if self.m_prev_question == self.get_music() \
-                and (len(self.m_questions) > 1 or self.header.random_transpose):
-                continue
-            break
-        self.m_prev_question = self.get_music()
-    def _find_random_transpose(self, key):
-        """
-        Pick a random interval to transpose the question. While doing this,
-        make sure there are not more than MAX_ACC accidentals.
-        """
-        max_acc = 5
-        tone, minmaj = string.split(key, " ")
-        k = mpd.MusicalPitch.new_from_notename(tone).get_octave_notename()
-        #FIXME this list say what key signatures are allowed in sing-chord
-        # lesson files. Get the correct values and document them.
-        kv = ['des', 'aes', 'ees', 'bes', 'f', 'c',
-              'g', 'd', 'a', 'e', 'b', 'fis', 'cis', 'gis']
-        # na tell the number of accidentals (# is positive, b is negative)
-        # the question has from the lessonfile before anything is transpose.
-        na = kv.index(k) - 5
-        if minmaj == '\\minor':
-            na -= 3
-        # the number of steps down the circle of fifths we can go
-        n_down = -max_acc-na
-        # the number of steps up the circle of fifths we can go
-        n_up = max_acc - na
-        # The keys in the dict say how many steps up or down in the
-        # circle of fifths we go if we transpose.
-        d = {
-              -10: '-M6', #c -> eses
-               -9: '-a2', #c -> beses
-               -8: '-a5', #c -> fes
-               -7: '-au', #c -> ces
-               -6: '-a4', #c -> ges
-               -5: 'm2', # c -> des
-               -4: '-M3',# c -> as
-               -3: 'm3', # c -> es
-               -2: '-M2', # c -> bes
-               -1: '4', # c -> f
-                0: 'u',
-                1: '-4', # c -> g,
-                2: 'M2', # c -> d
-                3: '-m3',# c -> a
-                4: 'M3', # c -> e
-                5: '-m2', # c -> b
-                6: 'a4', # c -> fis
-                7: 'au', #c -> cis
-                8: 'a5', # c -> gis
-                9: 'a2', # c -> dis
-                10: 'M6', # c -> ais
-            }
-        interv = mpd.Interval()
-        interv.set_from_string(d[random.choice(range(n_down, n_up+1))])
-        return mpd.MusicalPitch.new_from_notename("c'") + interv
-
+    def handle_random_transpose_is_yes(self):
+        self.header.random_transpose = ['accidentals', -5, 5]
 
 class IdByNameLessonfile(LessonfileCommon):
     def __init__(self, filename):
@@ -280,7 +309,6 @@ class IdByNameLessonfile(LessonfileCommon):
         """
         return self.m_names[self.m_questions[self._idx]['name']]
 
-
 class ChordLessonfile(LessonfileCommon):
     def __init__(self, filename):
         LessonfileCommon.__init__(self)
@@ -303,7 +331,7 @@ class ChordLessonfile(LessonfileCommon):
                     and question['toptone'] not in self.m_toptones:
                 self.m_toptones.append(question['toptone'])
     def get_music(self):
-        """ Returns the music for the curretly selected question.
+        """ Returns the music for the currently selected question.
         The function will transpose the question if the lessonfile
         header say random_transpose = 1
         """
@@ -348,7 +376,7 @@ class LessonFileManager:
                   or not os.path.isfile(self.get_complete_filename(collection, filename)):
                     continue
                 try:
-                    p = dataparser.Dataparser(predef)
+                    p = dataparser.Dataparser(predef, lessonfile_functions)
                     p.parse_file(self.get_complete_filename(collection, filename), 1)
                 except dataparser.DataparserException:
                     self.m_invalid_files.append((collection, filename))
@@ -404,3 +432,8 @@ class LessonFileManager:
         else:
             return []
 
+if __name__ == '__main__':
+    import src, src.i18n
+    p = LessonfileCommon()
+    p._parse_file(sys.argv[1])
+    print p.header.random_transpose
