@@ -16,7 +16,6 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import sys, os, time, random
-
 # Hack to make module testing work.
 __builtins__['app_running'] = 'solfege'
 
@@ -107,7 +106,6 @@ class SplashWin(gtk.Window):
         gtk.Window.__init__(self, gtk.WINDOW_POPUP)
         self.set_position(gtk.WIN_POS_CENTER)
         self.set_resizable(gtk.TRUE)
-        self.set_name("SplashWindow")
         frame = gtk.Frame()
         frame.set_shadow_type(gtk.SHADOW_OUT)
         self.add(frame)
@@ -119,7 +117,13 @@ class SplashWin(gtk.Window):
         vbox.pack_start(l)
         l = gtk.Label("http://www.solfege.org")
         vbox.pack_start(l)
+        self.g_infolabel = gtk.Label('')
+        vbox.pack_start(self.g_infolabel)
         self.show_all()
+    def show_progress(self, txt):
+        self.g_infolabel.set_text(txt)
+        while gtk.events_pending():
+            gtk.mainiteration(0)
 
 if not filter(lambda a: a in sys.argv, ['--no-splash', '--usage', '-?', '--gtk-help']):
     splash_win = SplashWin()
@@ -140,11 +144,18 @@ for a in ('--no-sound', '--verbose-sound-init'):
         args.append(a)
         del sys.argv[sys.argv.index(a)]
 
+if splash_win:
+    splash_win.show_progress("importing GNOME modules")
+
 import gnome, gnome.ui
 # FIXME we set this because it is not yet added to PyGNOME2
 gnome.ui.PAD=8
 gnome.ui.PAD_SMALL=4
 gnome.ui.PAD_BIG=12
+
+if splash_win:
+    splash_win.show_progress("importing application modules")
+
 import const, string
 import app
 from htmlwidget import HtmlWidget
@@ -255,6 +266,9 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         if 1:
             im = gtk.Image()
             im.set_from_file(os.path.join("graphics", "solfege.png"))
+            trans = _("SOLFEGETRANSLATORS")
+            if trans == 'SOLFEGETRANSLATORS':
+                trans = ""
             self.g_about_window = gnome.ui.About("GNU Solfege",
                   configureoutput.VERSION_STRING,
                   "Copyright (C) 2000, 2001, 2002 Tom Cato Amundsen",
@@ -265,15 +279,13 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                   'Joe Lee %s' % _("(sound code for the MS Windows port)"),
                   ],
                   ["Tom Cato Amundsen"],
-                   "\n".join(["Tom Cato Amundsen", "Michael Shigorin",
-                   "Keld Simonsen", "F(r)eddy SpierenBU(r)G",
-                   "Jean Orloff", "Mauro Colorio", "Oliver Vollmer"]),
+                  trans,
                   im.get_pixbuf())
             #self.g_about_window.connect('destroy', self.hide_about_window)
             #self.g_about_window.show()
             #FIXME this sucks.
             i = self.g_about_window.run()
-            self.g_about_window.destroy()
+            #self.g_about_window.destroy()
     def hide_about_window(self, widget):
         self.g_about_window.destroy()
         self.g_about_window = None
@@ -375,23 +387,22 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         self.g_menubar.show_all()
     def create_file_menu(self, ag):
         menu = gtk.Menu()
+        if self.get_bool("gui/menus_have_tearoff"):
+            item = gtk.TearoffMenuItem()
+            menu.add(item)
         for ex in const.exercises:
             box = gtk.HBox()
             box.set_spacing(4)
             if const.exercisedata[ex][1]:
+                item = gtk.ImageMenuItem(const.exercisedata[ex][0])
                 im = gtk.Image()
                 im.set_from_file(os.path.join('graphics', const.exercisedata[ex][1]))
                 im.set_from_pixbuf(im.get_pixbuf().scale_simple(16, 16, gtk.gdk.INTERP_TILES))
-                box.pack_start(im, gtk.FALSE, gtk.FALSE)
-            item = gtk.MenuItem()
-            item.add(box)
-            label = gtk.AccelLabel('')
-            label.set_text_with_mnemonic(const.exercisedata[ex][0])
+                item.set_image(im)
+            else:
+                item = gtk.MenuItem(const.exercisedata[ex][0])
             if const.exercisedata[ex][2]:
                 item.add_accelerator('activate', ag, const.exercisedata[ex][2], const.exercisedata[ex][3], gtk.ACCEL_VISIBLE)
-                label.set_accel_widget(item)
-            box.pack_start(label, gtk.TRUE, gtk.TRUE)
-            label.set_alignment(0, 0.5)
             item.connect('activate', lambda o, self=self, ex=ex: self.m_app.handle_href('solfege:practise/'+ex))
             menu.add(item)
         item = gtk.MenuItem()
@@ -406,6 +417,9 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         return menu
     def create_view_menu(self, ag):
         menu = gtk.Menu()
+        if self.get_bool("gui/menus_have_tearoff"):
+            item = gtk.TearoffMenuItem()
+            menu.add(item)
         # toolbar visible?
         toolitem = gtk.CheckMenuItem(_("_Toolbar"))
         toolitem.connect('toggled', self.on_view_menu_toolbar_visible_toggled)
@@ -470,7 +484,10 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
             self.get_dock_item_by_name("navbar").hide()
     def create_help_menu(self, ag):
         menu = gtk.Menu()
-        item = create_menu_item(_("_Help on current exercise"),
+        if self.get_bool("gui/menus_have_tearoff"):
+            item = gtk.TearoffMenuItem()
+            menu.add(item)
+        item = create_stock_menu_item('gtk-help', _("_Help on current exercise"),
                             lambda o, self=self: self.m_app.please_help_me(),
                             ag, gtk.keysyms.F1, 0)
         menu.add(item)
@@ -499,7 +516,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         pass
     def quit_program(self, w=None):
         self.m_app.quit_program()
-        gtk.mainquit()
+        gtk.main_quit()
     def setup_toolbar(self):
         ## navbar
         self.g_navbar = gtk.Toolbar()
@@ -559,18 +576,15 @@ def create_stock_menu_item(stock, txt, callback, ag, accel_key, accel_mod):
     box.set_spacing(gnome.ui.PAD_SMALL)
     im = gtk.Image()
     im.set_from_stock(stock, gtk.ICON_SIZE_MENU)
-    box.pack_start(im, gtk.FALSE, gtk.FALSE)
-    item = gtk.MenuItem()
-    item.add(box)
-    label = gtk.AccelLabel('')
-    label.set_text_with_mnemonic(txt)
+    item = gtk.ImageMenuItem(txt)
+    item.set_image(im)
     item.add_accelerator('activate', ag, accel_key, accel_mod, gtk.ACCEL_VISIBLE)
-    label.set_accel_widget(item)
-    box.pack_start(label, gtk.TRUE, gtk.TRUE)
-    label.set_alignment(0, 0.5)
     item.connect('activate', callback)
     return item
 
+if splash_win:
+    splash_win.show_progress("running gnome.program_init")
+
 gnome.program_init('solfege%s%s' % (configureoutput.MAJOR_VERSION,
                                     configureoutput.MINOR_VERSION),
                    configureoutput.VERSION_STRING)
@@ -580,6 +594,8 @@ prog.parse_args()
 import locale
 locale.setlocale(locale.LC_NUMERIC, "C")
 
+if splash_win:
+    splash_win.show_progress("creating MainWin")
 w = MainWin(args)
 w.show()
 w.post_constructor()
