@@ -16,7 +16,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import os.path, shutil, __main__
+
+if __name__ == '__main__':
+    import sys;
+    sys.path.append(".")
+
 import src.configureoutput
+import cfg
 
 def copy_rc_file():
     __main__.rc_copied = 0
@@ -36,7 +42,6 @@ def copy_rc_file():
     if not os.path.isfile(rc19):
         for rcfn in (rc15, rc14, rc13, rc12, rc11, rc10):
             if os.path.isfile(rcfn):
-                print "rcfile: copy %s -> %s" % (rcfn, rc19)
                 shutil.copy(rcfn, rc19)
                 __main__.rc_copied = 1
                 break
@@ -48,5 +53,21 @@ def copy_rc_file():
             f = open(rc19, "w")
             f.write(s)
             f.close()
+    if src.configureoutput.MAJOR_VERSION == 2:
+        create_rc2dot0()
 
+def create_rc2dot0():
+    if not os.path.isfile(os.path.expanduser("~/.solfegerc2.0")):
+        d = {}
+        cfg.parse_file_into_dict(d, os.path.expanduser("~/.solfegerc1.9"))
+        data = {}
+        for k in ['user', 'sound', 'lessoncollections', 'config', 'gui']:
+            data[k] = d[k]
+        del data['gui']['button_height']
+        cfg.dump(data, os.path.expanduser("~/.solfegerc2.0"))
 
+if __name__ == '__main__':
+    import sys;
+    sys.path.append(".")
+    copy_rc_file()
+    create_rc2dot0()
