@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,32 +17,32 @@
 
 import gtk, gnome, gu
 from htmlwidget import HtmlWidget
-from i18n import _
+import dataparser
 
-class SelectLessonfileWidget(gtk.GtkFrame):
+class SelectLessonfileWidget(gtk.Frame):
     """
     The class will parse call the teacher to parse the
     lessonfile because the widget need some data from the
     lessonfile header.
     """
     def __init__(self, teacher, win, change_cb):
-        gtk.GtkFrame.__init__(self, _("Lesson file"))
+        gtk.Frame.__init__(self, _("Lesson file"))
         self.m_t = teacher
+        self.m_ui = win
         self.change_cb = change_cb
-        vbox = gtk.GtkVBox()
-        vbox.set_border_width(gnome.uiconsts.PAD)
-        vbox.set_spacing(gnome.uiconsts.PAD)
+        vbox = gtk.VBox()
+        vbox.set_border_width(gnome.ui.PAD)
+        vbox.set_spacing(gnome.ui.PAD)
         self.add(vbox)
-        # the box the combos go into
+        # the box the optionmenus go into
         hbox = gu.bHBox(vbox, gtk.FALSE)
+        hbox.set_homogeneous(gtk.TRUE)
 
-        self.g_collection_combo = gtk.GtkCombo()
-        self.g_collection_combo.entry.set_editable(gtk.FALSE)
-        hbox.pack_start(self.g_collection_combo)
+        self.g_collection = gtk.OptionMenu()
+        hbox.pack_start(self.g_collection)
 
-        self.g_file_combo = gtk.GtkCombo()
-        self.g_file_combo.entry.set_editable(gtk.FALSE)
-        hbox.pack_start(self.g_file_combo)
+        self.g_files = gtk.OptionMenu()
+        hbox.pack_start(self.g_files)
 
         # descriptions
         hbox = gu.bHBox(vbox, gtk.FALSE)
@@ -50,17 +50,17 @@ class SelectLessonfileWidget(gtk.GtkFrame):
         self.g_title = gu.bLabel(hbox, "", gtk.FALSE)
 
         #details
-        self.g_toggle_description = gtk.GtkToggleButton(_("Details"))
+        self.g_toggle_description = gtk.ToggleButton(_("Details"))
         self.g_toggle_description.connect('clicked', self.toggle_lessonfile_details)
         hbox.pack_end(self.g_toggle_description, gtk.FALSE, gtk.FALSE)
-        self.g_description_frame = gtk.GtkFrame()
+        self.g_description_frame = gtk.Frame()
         self.g_lessonfile_details = HtmlWidget(self.m_t.m_app.handle_href, None)
         self.g_description_frame.add(self.g_lessonfile_details)
         vbox.pack_start(self.g_description_frame)
         self.m_lock = 0
         self.update()
-        self.g_collection_combo.entry.connect('changed', self.change_collection)
-        self.g_file_combo.entry.connect('changed', self.change_file)
+        self.g_collection.connect('changed', self.change_collection)
+        self.g_files.connect('changed', self.change_file)
         self._fw = self.m_t.add_watch('lessonfile', self._lessonfilewatch)
         self._cw = self.m_t.add_watch('lessoncollection', self._lessoncollectionwatch)
     def _lessonfilewatch(self, s):
@@ -69,17 +69,24 @@ class SelectLessonfileWidget(gtk.GtkFrame):
     def _lessoncollectionwatch(self, s):
         self.m_t.remove_watch('lessoncollection', self._cw)
         self.m_lock = self.m_lock + 1
-        self.g_collection_combo.entry.set_text(self.m_t.get_string(s))
         self.m_lock = self.m_lock - 1
         self._cw = self.m_t.add_watch('lessoncollection', self._lessoncollectionwatch)
     def change_collection(self, widget):
-        self.m_t.set_lessoncollection(widget.get_text())
+        try:
+            self.m_t.set_lessoncollection(self.m_t.m_app.lessonfile_manager.get_collections()[widget.get_history()])
+        except dataparser.DataparserException, e:
+            self.m_ui.display_error_message(str(e))
+            self.m_t.m_P = None
         self.update(1)
         self.change_cb()
     def change_file(self, widget):
         if self.m_lock > 0:
             return
-        self.m_t.set_lessonfile(widget.get_text())
+        try:
+            self.m_t.set_lessonfile(self.m_t.m_app.lessonfile_manager.get_filenames(self.m_t.get_string('lessoncollection'), self.m_t.m_content_type)[widget.get_history()])
+        except dataparser.DataparserException, e:
+            self.m_ui.display_error_message(str(e))
+            self.m_t.m_P = None
         self.update(2)
         self.change_cb()
     def update(self, level=0):
@@ -89,22 +96,35 @@ class SelectLessonfileWidget(gtk.GtkFrame):
         """
         if self.m_lock > 0:
             return
-        self.m_lock = self.m_lock + 1
+        self.m_lock += 1
         if level == 0:
-            self.g_collection_combo.set_popdown_strings(
-                    self.m_t.m_app.lessonfile_manager.get_collections())
-            self.g_collection_combo.entry.set_text(
-                    self.m_t.get_string('lessoncollection'))
+            if not self.g_collection.get_menu():
+                menu = gtk.Menu()
+                for coll in self.m_t.m_app.lessonfile_manager.get_collections():
+                    menu.add(gtk.MenuItem(coll))
+                self.g_collection.set_menu(menu)
+                self.g_collection.set_history(self.m_t.m_app.lessonfile_manager.get_collections().index(self.m_t.get_string('lessoncollection')))
         if level <= 1:
             F = self.m_t.m_app.lessonfile_manager.get_filenames( \
                     self.m_t.get_string('lessoncollection'), self.m_t.m_content_type)
             if F:
-                self.g_file_combo.set_popdown_strings(F)
-                self.g_file_combo.entry.set_text(self.m_t.get_string('lessonfile'))
-                self.g_file_combo.set_sensitive(gtk.TRUE)
+                menu = self.g_files.get_menu()
+                if menu:
+                    self.g_files.remove_menu()
+                    menu.destroy()
+                menu = gtk.Menu()
+                for lessonfile in F:
+                    menu.add(gtk.MenuItem(lessonfile))
+                self.g_files.set_menu(menu)
+                menu.show_all()
+                self.g_files.set_sensitive(gtk.TRUE)
+                self.g_files.set_history(self.m_t.m_app.lessonfile_manager.get_filenames(self.m_t.get_string('lessoncollection'), self.m_t.m_content_type).index(self.m_t.get_string('lessonfile')))
             else:
-                self.g_file_combo.entry.set_text('')
-                self.g_file_combo.set_sensitive(gtk.FALSE)
+                menu = self.g_files.get_menu()
+                if menu:
+                    self.g_files.remove_menu()
+                    menu.destroy()
+                self.g_files.set_sensitive(gtk.FALSE)
                 self.g_title.set_text('')
                 self.g_description_frame.hide()
                 #self.g_lessonfile_details.source("<html></html>")
@@ -128,7 +148,7 @@ class SelectLessonfileWidget(gtk.GtkFrame):
            self.g_toggle_description.set_sensitive(gtk.FALSE)
         self.m_lock = self.m_lock - 1
     def toggle_lessonfile_details(self, widget=None):
-        if widget.active:
+        if widget.get_active():
             self.g_description_frame.show()
         else:
             self.g_description_frame.hide()
