@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -129,7 +129,7 @@ class AbstractStatistics:
         return t
     def get_percentage_correct(self, st, key):
         """
-        This was added to be used for harmonic-intervall.
+        This was added to be used for harmonic-interval.
         """
         if not st.has_key(key):
             return 0.0
@@ -240,10 +240,11 @@ class LessonStatistics(AbstractStatistics):
             self.m_cur_file))).read())
 
 
-class IntervallStatistics(Statistics):
+class IntervalStatistics(Statistics):
     def key_to_pretty_name(self, key):
-        return utils.int_to_intervallname(key, 1, 1)
+        return utils.int_to_intervalname(key, 1, 1)
 
-class HarmonicIntervallStatistics(Statistics):
+class HarmonicIntervalStatistics(Statistics):
     def key_to_pretty_name(self, key):
-        return utils.int_to_intervallname(key, 1, 0)
+        return utils.int_to_intervalname(key, 1, 0)
+
