@@ -1,9 +1,10 @@
-#!/usr/bin/python2.1
+#!/usr/bin/python2.2
+
+import pygtk
+pygtk.require("2.0")
 import profile, os
 import sys, types
 
-sys.path.append("/usr/lib/python2.1/site-packages")
-
 if os.getcwd()[-4:] == "test":
    sys.path.append("..")
 else:
@@ -29,13 +30,13 @@ def vis():
 
 
 def pass1():
-        for n in range(30):
+        for n in range(200):
                 score = mpd.parser.parse_to_score_object(music)
-                eng = score.get_engravers(20)
+                #eng = score.get_engravers(20)
 def pass2():
     for x in range(20):
         score = mpd.parser.parse_to_score_object(music)
-        #eng = score.get_engravers(20)
+        eng = score.get_engravers(20)
 
 import time
 t1 = time.clock()
